#!/usr/bin/env python

# -*- coding: ascii -*-

import sys
import os
import subprocess

p = subprocess.Popen('find dist -name "site-packages" 2>/dev/null', shell=1,
    stdout=subprocess.PIPE).stdout
sitepkgsdir = p.readline().strip('\n')
os.environ['PYTHONPATH'] = os.path.join(os.getcwd(), sitepkgsdir)
#print os.environ['PYTHONPATH']

try:
    cmd = 'python -t dist/bin/clive '
    for arg in sys.argv[1:]:
        a = arg.split('=')
        if len(a) == 2:
            s = '%s="%s"' % (a[0],a[1])
        else:
            s = a[0]
        cmd += (s + ' ')
    r = subprocess.call(cmd, shell=1)
    if r < 0:
        print >>sys.stderr, 'child terminated by signal', -r
except OSError, e:
    print >>sys.stderr, 'execution failed', e
except KeyboardInterrupt:
    pass
